/*
 * Copyright (c) 2023, Texas Instruments Incorporated - http://www.ti.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*
 *  ============ ti_msp_dl_config.h =============
 *  Configured MSPM0 DriverLib module declarations
 *
 *  DO NOT EDIT - This file is generated for the MSPM0L110X
 *  by the SysConfig tool.
 */
#ifndef ti_msp_dl_config_h
#define ti_msp_dl_config_h

#define CONFIG_MSPM0L110X

#if defined(__ti_version__) || defined(__TI_COMPILER_VERSION__)
#define SYSCONFIG_WEAK __attribute__((weak))
#elif defined(__IAR_SYSTEMS_ICC__)
#define SYSCONFIG_WEAK __weak
#elif defined(__GNUC__)
#define SYSCONFIG_WEAK __attribute__((weak))
#endif

#include <ti/devices/msp/msp.h>
#include <ti/driverlib/driverlib.h>
#include <ti/driverlib/m0p/dl_core.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 *  ======== SYSCFG_DL_init ========
 *  Perform all required MSP DL initialization
 *
 *  This function should be called once at a point before any use of
 *  MSP DL.
 */


/* clang-format off */

#define POWER_STARTUP_DELAY                                                (16)


#define CPUCLK_FREQ                                                     32000000



/* Defines for TIMER_0 */
#define TIMER_0_INST                                                     (TIMG0)
#define TIMER_0_INST_IRQHandler                                 TIMG0_IRQHandler
#define TIMER_0_INST_INT_IRQN                                   (TIMG0_INT_IRQn)
#define TIMER_0_INST_LOAD_VALUE                                         (62499U)




/* Defines for I2C */
#define I2C_INST                                                            I2C0
#define I2C_INST_IRQHandler                                      I2C0_IRQHandler
#define I2C_INST_INT_IRQN                                          I2C0_INT_IRQn
#define I2C_TARGET_OWN_ADDR                                                 0x48
#define GPIO_I2C_SDA_PORT                                                  GPIOA
#define GPIO_I2C_SDA_PIN                                           DL_GPIO_PIN_0
#define GPIO_I2C_IOMUX_SDA                                        (IOMUX_PINCM1)
#define GPIO_I2C_IOMUX_SDA_FUNC                         IOMUX_PINCM1_PF_I2C0_SDA
#define GPIO_I2C_SCL_PORT                                                  GPIOA
#define GPIO_I2C_SCL_PIN                                           DL_GPIO_PIN_1
#define GPIO_I2C_IOMUX_SCL                                        (IOMUX_PINCM2)
#define GPIO_I2C_IOMUX_SCL_FUNC                         IOMUX_PINCM2_PF_I2C0_SCL



/* Defines for ADC12_0 */
#define ADC12_0_INST                                                        ADC0
#define ADC12_0_INST_IRQHandler                                  ADC0_IRQHandler
#define ADC12_0_INST_INT_IRQN                                    (ADC0_INT_IRQn)
#define ADC12_0_ADCMEM_0                                      DL_ADC12_MEM_IDX_0
#define ADC12_0_ADCMEM_0_REF                     DL_ADC12_REFERENCE_VOLTAGE_VDDA
#define ADC12_0_ADCMEM_0_REF_VOLTAGE                                          -1 // VDDA cannot be determined
#define ADC12_0_ADCMEM_1                                      DL_ADC12_MEM_IDX_1
#define ADC12_0_ADCMEM_1_REF                     DL_ADC12_REFERENCE_VOLTAGE_VDDA
#define ADC12_0_ADCMEM_1_REF_VOLTAGE                                          -1 // VDDA cannot be determined
#define ADC12_0_ADCMEM_2                                      DL_ADC12_MEM_IDX_2
#define ADC12_0_ADCMEM_2_REF                     DL_ADC12_REFERENCE_VOLTAGE_VDDA
#define ADC12_0_ADCMEM_2_REF_VOLTAGE                                          -1 // VDDA cannot be determined
#define ADC12_0_ADCMEM_3                                      DL_ADC12_MEM_IDX_3
#define ADC12_0_ADCMEM_3_REF                     DL_ADC12_REFERENCE_VOLTAGE_VDDA
#define ADC12_0_ADCMEM_3_REF_VOLTAGE                                          -1 // VDDA cannot be determined
#define GPIO_ADC12_0_C1_PORT                                               GPIOA
#define GPIO_ADC12_0_C1_PIN                                       DL_GPIO_PIN_26
#define GPIO_ADC12_0_C0_PORT                                               GPIOA
#define GPIO_ADC12_0_C0_PIN                                       DL_GPIO_PIN_27
#define GPIO_ADC12_0_C9_PORT                                               GPIOA
#define GPIO_ADC12_0_C9_PIN                                       DL_GPIO_PIN_15
#define GPIO_ADC12_0_C8_PORT                                               GPIOA
#define GPIO_ADC12_0_C8_PIN                                       DL_GPIO_PIN_16



/* Port definition for Pin Group GPIO_Other */
#define GPIO_Other_PORT                                                  (GPIOA)

/* Defines for BSL_Mode: GPIOA.18 with pinCMx 19 on package pin 22 */
#define GPIO_Other_BSL_Mode_PIN                                 (DL_GPIO_PIN_18)
#define GPIO_Other_BSL_Mode_IOMUX                                (IOMUX_PINCM19)
/* Port definition for Pin Group GPIO_PWR */
#define GPIO_PWR_PORT                                                    (GPIOA)

/* Defines for P0_PWR_OFF: GPIOA.2 with pinCMx 3 on package pin 6 */
#define GPIO_PWR_P0_PWR_OFF_PIN                                  (DL_GPIO_PIN_2)
#define GPIO_PWR_P0_PWR_OFF_IOMUX                                 (IOMUX_PINCM3)
/* Defines for P1_PWR_OFF: GPIOA.3 with pinCMx 4 on package pin 7 */
#define GPIO_PWR_P1_PWR_OFF_PIN                                  (DL_GPIO_PIN_3)
#define GPIO_PWR_P1_PWR_OFF_IOMUX                                 (IOMUX_PINCM4)
/* Defines for P2_PWR_OFF: GPIOA.4 with pinCMx 5 on package pin 8 */
#define GPIO_PWR_P2_PWR_OFF_PIN                                  (DL_GPIO_PIN_4)
#define GPIO_PWR_P2_PWR_OFF_IOMUX                                 (IOMUX_PINCM5)
/* Defines for P3_PWR_OFF: GPIOA.5 with pinCMx 6 on package pin 9 */
#define GPIO_PWR_P3_PWR_OFF_PIN                                  (DL_GPIO_PIN_5)
#define GPIO_PWR_P3_PWR_OFF_IOMUX                                 (IOMUX_PINCM6)
/* Defines for P4_PWR_OFF: GPIOA.6 with pinCMx 7 on package pin 10 */
#define GPIO_PWR_P4_PWR_OFF_PIN                                  (DL_GPIO_PIN_6)
#define GPIO_PWR_P4_PWR_OFF_IOMUX                                 (IOMUX_PINCM7)
/* Defines for P5_PWR_OFF: GPIOA.7 with pinCMx 8 on package pin 11 */
#define GPIO_PWR_P5_PWR_OFF_PIN                                  (DL_GPIO_PIN_7)
#define GPIO_PWR_P5_PWR_OFF_IOMUX                                 (IOMUX_PINCM8)
/* Defines for P6_PWR_OFF: GPIOA.8 with pinCMx 9 on package pin 12 */
#define GPIO_PWR_P6_PWR_OFF_PIN                                  (DL_GPIO_PIN_8)
#define GPIO_PWR_P6_PWR_OFF_IOMUX                                 (IOMUX_PINCM9)
/* Defines for PSE_PWR_ON: GPIOA.9 with pinCMx 10 on package pin 13 */
#define GPIO_PWR_PSE_PWR_ON_PIN                                  (DL_GPIO_PIN_9)
#define GPIO_PWR_PSE_PWR_ON_IOMUX                                (IOMUX_PINCM10)
/* Port definition for Pin Group GPIO_nFLT */
#define GPIO_nFLT_PORT                                                   (GPIOA)

/* Defines for P0_nFLT: GPIOA.10 with pinCMx 11 on package pin 14 */
// pins affected by this interrupt request:["P0_nFLT"]
#define GPIO_nFLT_INT_IRQN                                      (GPIOA_INT_IRQn)
#define GPIO_nFLT_INT_IIDX                      (DL_INTERRUPT_GROUP1_IIDX_GPIOA)
#define GPIO_nFLT_P0_nFLT_IIDX                              (DL_GPIO_IIDX_DIO10)
#define GPIO_nFLT_P0_nFLT_PIN                                   (DL_GPIO_PIN_10)
#define GPIO_nFLT_P0_nFLT_IOMUX                                  (IOMUX_PINCM11)
/* Defines for P1_nFLT: GPIOA.11 with pinCMx 12 on package pin 15 */
#define GPIO_nFLT_P1_nFLT_PIN                                   (DL_GPIO_PIN_11)
#define GPIO_nFLT_P1_nFLT_IOMUX                                  (IOMUX_PINCM12)
/* Defines for P2_nFLT: GPIOA.12 with pinCMx 13 on package pin 16 */
#define GPIO_nFLT_P2_nFLT_PIN                                   (DL_GPIO_PIN_12)
#define GPIO_nFLT_P2_nFLT_IOMUX                                  (IOMUX_PINCM13)
/* Defines for P3_nFLT: GPIOA.13 with pinCMx 14 on package pin 17 */
#define GPIO_nFLT_P3_nFLT_PIN                                   (DL_GPIO_PIN_13)
#define GPIO_nFLT_P3_nFLT_IOMUX                                  (IOMUX_PINCM14)
/* Defines for P4_nFLT: GPIOA.14 with pinCMx 15 on package pin 18 */
#define GPIO_nFLT_P4_nFLT_PIN                                   (DL_GPIO_PIN_14)
#define GPIO_nFLT_P4_nFLT_IOMUX                                  (IOMUX_PINCM15)
/* Defines for P5_nFLT: GPIOA.17 with pinCMx 18 on package pin 21 */
#define GPIO_nFLT_P5_nFLT_PIN                                   (DL_GPIO_PIN_17)
#define GPIO_nFLT_P5_nFLT_IOMUX                                  (IOMUX_PINCM18)

/* clang-format on */

void SYSCFG_DL_init(void);
void SYSCFG_DL_initPower(void);
void SYSCFG_DL_GPIO_init(void);
void SYSCFG_DL_SYSCTL_init(void);
void SYSCFG_DL_TIMER_0_init(void);
void SYSCFG_DL_I2C_init(void);
void SYSCFG_DL_ADC12_0_init(void);



#ifdef __cplusplus
}
#endif

#endif /* ti_msp_dl_config_h */
